@@ -2,7 +2,10 @@
 from bencode import bencode
 import itertools
 
-from django.utils.hashcompat import sha_constructor
+try:
+    from hashlib import sha1
+except ImportError:
+    from django.utils.hashcompat import sha_constructor as sha1
 
 
 class Manifest(object):
@@ -17,4 +20,4 @@ class Manifest(object):
 
     def revision(self):
         revision = list(itertools.chain(self.fallback(), self.network(), self.cache()))
-        return sha_constructor(bencode(revision)).hexdigest()[:7]
+        return sha1(bencode(revision)).hexdigest()[:7]
